# Overview
Implement something similar to Wireshark but in Python/Scapy.

# But why?
Idk. Why not.

# Install?
```bash
pip install scapyshark

# Or
git clone https://github.com/bannsec/scapyshark.git
cd scapyshark
pip install .
```

# Run?
```bash
sudo -E $(which scapyshark)

# Or if only replaying and do not need to sniff
scapyshark
```
